"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const actions_1 = require("src/actions/");
const routeList_1 = require("src/routeList");
const react_native_splash_screen_1 = tslib_1.__importDefault(require("react-native-splash-screen"));
const errors_1 = require("src/lib/errors");
exports.showErrorScreen = (error) => dispatch => {
    const appError = error.constructor === errors_1.AppError
        ? error
        : new errors_1.AppError(errors_1.ErrorCode.Unknown, error);
    return dispatch(actions_1.navigationActions.navigate({
        routeName: routeList_1.routeList.Exception,
        params: {
            returnTo: appError.navigateTo,
            error: appError,
        },
    }));
};
exports.initApp = (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    try {
        yield backendMiddleware.initStorage();
        const storedSettings = yield backendMiddleware.storageLib.get.settingsObject();
        // locale setup
        // if (storedSettings.locale) I18n.locale = storedSettings.locale
        // else storedSettings.locale = I18n.locale
        react_native_splash_screen_1.default.hide();
        return dispatch(exports.loadSettings(storedSettings));
    }
    catch (e) {
        return dispatch(exports.showErrorScreen(new errors_1.AppError(errors_1.ErrorCode.WalletInitFailed, e, routeList_1.routeList.Landing)));
    }
});
exports.loadSettings = (settings) => ({
    type: 'LOAD_SETTINGS',
    value: settings,
});
