"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const routeList_1 = require("src/routeList");
const jolocom_lib_1 = require("jolocom-lib");
const interactionTokens_1 = require("src/lib/storage/interactionTokens");
const errors_1 = require("src/lib/errors");
const modifiers_1 = require("src/actions/modifiers");
/**
 * NOTE: navigate and navigatorReset both dispatch the navigation actions but
 * the actions are not handled by our reducers. Dispatching is useful for testing
 * (comparing snapshots of store actions) and it makes typescript happy
 */
exports.navigate = (options) => dispatch => {
    return Promise.resolve();
};
exports.navigatorReset = (newScreen) => dispatch => {
    return Promise.resolve();
};
exports.navigatorResetHome = () => dispatch => dispatch(exports.navigatorReset({ routeName: routeList_1.routeList.Home }));
/**
 * The function that parses a deep link to get the route name and params
 * It then matches the route name and dispatches a corresponding action
 * @param url - a deep link string with the following schema: appName://routeName/params
 */
exports.handleDeepLink = (url) => (dispatch, getState, backendMiddleware) => {
    // The identityWallet is initialised before the deep link is handled. If it
    // is not initialized, then we may not even have an identity.
    if (!backendMiddleware.identityWallet) {
        return dispatch(exports.navigate({
            routeName: routeList_1.routeList.Landing,
        }));
    }
    let routeName = '', params = '';
    if (url) {
        const [scheme, uri] = url.split('://');
        if (scheme && uri) {
            const parts = uri.split('/');
            if (scheme.startsWith('http')) {
                routeName = parts[1];
                params = parts[2];
            }
            else {
                routeName = parts[0];
                params = parts[1];
            }
        }
    }
    const supportedRoutes = ['consent', 'payment', 'authenticate'];
    if (supportedRoutes.includes(routeName)) {
        const interactionToken = jolocom_lib_1.JolocomLib.parse.interactionToken.fromJWT(params);
        const handler = interactionTokens_1.interactionHandlers[interactionToken.interactionType];
        if (handler) {
            return dispatch(modifiers_1.withLoading(modifiers_1.withErrorScreen(handler(interactionToken, true))));
        }
    }
    /** @TODO Use error code */
    throw new errors_1.AppError(errors_1.ErrorCode.ParseJWTFailed, new Error('Could not handle interaction token'));
};
