"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const actions_1 = require("src/actions");
const routeList_1 = require("src/routeList");
const _1 = require(".");
const react_native_1 = require("react-native");
const jolocom_lib_1 = require("jolocom-lib");
const errors_1 = require("src/lib/errors");
const helper_1 = require("jolocom-lib/js/utils/helper");
const utils_1 = require("./utils");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
exports.consumeAuthenticationRequest = (authenticationRequest, isDeepLinkInteraction = false) => (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { identityWallet, registry } = backendMiddleware;
    yield identityWallet.validateJWT(authenticationRequest);
    const requester = yield registry.resolve(helper_1.keyIdToDid(authenticationRequest.issuer));
    const requesterSummary = utils_1.generateIdentitySummary(requester);
    const authenticationDetails = {
        requester: requesterSummary,
        callbackURL: authenticationRequest.interactionToken.callbackURL,
        description: authenticationRequest.interactionToken.description,
        requestJWT: authenticationRequest.encode(),
    };
    return dispatch(actions_1.navigationActions.navigate({
        routeName: routeList_1.routeList.AuthenticationConsent,
        params: { isDeepLinkInteraction, authenticationDetails },
        key: 'authenticationRequest',
    }));
});
exports.sendAuthenticationResponse = (isDeepLinkInteraction, authenticationDetails) => (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { identityWallet } = backendMiddleware;
    const { callbackURL, requestJWT, description } = authenticationDetails;
    const password = yield backendMiddleware.keyChainLib.getPassword();
    const decodedAuthRequest = jolocom_lib_1.JolocomLib.parse.interactionToken.fromJWT(requestJWT);
    const response = yield identityWallet.create.interactionTokens.response.auth({ callbackURL, description }, password, decodedAuthRequest);
    if (isDeepLinkInteraction) {
        const callback = `${callbackURL}/${response.encode()}`;
        if (!(yield react_native_1.Linking.canOpenURL(callback))) {
            throw new errors_1.AppError(errors_1.ErrorCode.DeepLinkUrlNotFound);
        }
        return react_native_1.Linking.openURL(callback).then(() => dispatch(_1.cancelSSO));
    }
    yield node_fetch_1.default(callbackURL, {
        method: 'POST',
        body: JSON.stringify({ token: response.encode() }),
        headers: { 'Content-Type': 'application/json' },
    });
    return dispatch(_1.cancelSSO);
});
