"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const errors_1 = require("../../lib/errors");
const index_1 = require("./index");
const ramda_1 = require("ramda");
const http_1 = require("../../lib/http");
const jolocom_lib_1 = require("jolocom-lib");
const helper_1 = require("jolocom-lib/js/utils/helper");
const modifiers_1 = require("../modifiers");
const utils_1 = require("./utils");
exports.consumeCredentialOfferRequest = (credOfferRequest, isDeepLinkInteraction = false) => (dispatch, getState, { keyChainLib, identityWallet, registry }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    yield identityWallet.validateJWT(credOfferRequest, undefined, registry);
    const { interactionToken } = credOfferRequest;
    const { callbackURL } = interactionToken;
    if (!areRequirementsEmpty(interactionToken)) {
        throw new Error('Input requests are not yet supported on the wallet');
    }
    const requester = yield registry.resolve(helper_1.keyIdToDid(credOfferRequest.issuer));
    const requesterSummary = utils_1.generateIdentitySummary(requester);
    const selectedCredentialTypes = interactionToken.offeredTypes.map(type => ({
        type,
    }));
    const selectedMetadata = interactionToken.offeredTypes.map(type => ({
        issuer: {
            did: helper_1.keyIdToDid(credOfferRequest.issuer),
        },
        type,
        renderInfo: interactionToken.getRenderInfoForType(type) || {},
        metadata: interactionToken.getMetadataForType(type) || {},
    }));
    const password = yield keyChainLib.getPassword();
    const credOfferResponse = yield identityWallet.create.interactionTokens.response.offer({ callbackURL, selectedCredentials: selectedCredentialTypes }, password, credOfferRequest);
    const res = yield http_1.httpAgent.postRequest(callbackURL, { 'Content-Type': 'application/json' }, { token: credOfferResponse.encode() });
    const credentialReceive = jolocom_lib_1.JolocomLib.parse.interactionToken.fromJWT(res.token);
    return dispatch(modifiers_1.withLoading(modifiers_1.withErrorScreen(index_1.receiveExternalCredential(credentialReceive, requesterSummary, isDeepLinkInteraction, selectedMetadata), err => new errors_1.AppError(errors_1.ErrorCode.CredentialsReceiveFailed, err))));
});
const areRequirementsEmpty = (interactionToken) => ramda_1.compose(ramda_1.all(ramda_1.either(ramda_1.isNil, ramda_1.isEmpty)), ramda_1.map(interactionToken.getRequestedInputForType.bind(interactionToken)))(interactionToken.offeredTypes);
