"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const actions_1 = require("src/actions");
const routeList_1 = require("src/routeList");
const jolocom_lib_1 = require("jolocom-lib");
const react_native_1 = require("react-native");
const sso_1 = require("src/actions/sso");
const errors_1 = require("src/lib/errors");
const helper_1 = require("jolocom-lib/js/utils/helper");
const utils_1 = require("./utils");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
exports.consumePaymentRequest = (paymentRequest, isDeepLinkInteraction = false) => (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { identityWallet, registry } = backendMiddleware;
    yield identityWallet.validateJWT(paymentRequest, undefined, registry);
    const requester = yield registry.resolve(helper_1.keyIdToDid(paymentRequest.issuer));
    const requesterSummary = utils_1.generateIdentitySummary(requester);
    const paymentDetails = {
        receiver: {
            did: paymentRequest.issuer,
            address: paymentRequest.interactionToken.transactionOptions.to,
        },
        requester: requesterSummary,
        callbackURL: paymentRequest.interactionToken.callbackURL,
        amount: paymentRequest.interactionToken.transactionOptions.value,
        description: paymentRequest.interactionToken.description,
        requestJWT: paymentRequest.encode(),
    };
    return dispatch(actions_1.navigationActions.navigate({
        routeName: routeList_1.routeList.PaymentConsent,
        params: { isDeepLinkInteraction, paymentDetails },
        key: 'paymentRequest',
    }));
});
exports.sendPaymentResponse = (isDeepLinkInteraction, paymentDetails) => (dispatch, getState, backendMiddleware) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const { identityWallet } = backendMiddleware;
    const { callbackURL, requestJWT } = paymentDetails;
    // add loading screen here
    const password = yield backendMiddleware.keyChainLib.getPassword();
    const decodedPaymentRequest = jolocom_lib_1.JolocomLib.parse.interactionToken.fromJWT(requestJWT);
    const txHash = yield identityWallet.transactions.sendTransaction(decodedPaymentRequest.interactionToken, password);
    const response = yield identityWallet.create.interactionTokens.response.payment({ txHash }, password, decodedPaymentRequest);
    if (isDeepLinkInteraction) {
        const callback = `${callbackURL}/${response.encode()}`;
        if (!(yield react_native_1.Linking.canOpenURL(callback))) {
            throw new errors_1.AppError(errors_1.ErrorCode.DeepLinkUrlNotFound);
        }
        return react_native_1.Linking.openURL(callback).then(() => dispatch(sso_1.cancelSSO));
    }
    else {
        return node_fetch_1.default(callbackURL, {
            method: 'POST',
            body: JSON.stringify({ token: response.encode() }),
            headers: { 'Content-Type': 'application/json' },
        }).then(() => dispatch(sso_1.cancelSSO));
    }
});
