"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/**
 * Given an identity, returns an object satisfying the {@link IdentitySummary} interface.
 * @dev Currently used with the {@link IssuerCard} component
 * @note In case the identity does not contain a Public Profile credential,
 * the function will return a minimal default which can be rendered.
 * @param identity - Instance of identity to generate the summary for
 */
exports.generateIdentitySummary = (identity) => {
    const { publicProfile, did } = identity;
    if (!publicProfile) {
        return {
            did,
        };
    }
    const _a = publicProfile.claim, { id } = _a, parsedProfile = tslib_1.__rest(_a, ["id"]);
    return {
        did,
        publicProfile: parsedProfile,
    };
};
