"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const routeList_1 = require("src/routeList");
const strings_1 = tslib_1.__importDefault(require("src/locales/strings"));
const types_1 = require("./types");
exports.ErrorCode = types_1.ErrorCode;
const sentry_1 = require("src/lib/errors/sentry");
class AppError extends Error {
    constructor(code = types_1.ErrorCode.Unknown, origError, navigateTo = routeList_1.routeList.AppInit) {
        super(strings_1.default[code] || strings_1.default[types_1.ErrorCode.Unknown]);
        // this.code = code
        this.origError = origError;
        this.navigateTo = navigateTo;
    }
}
exports.AppError = AppError;
exports.errorTitleMessages = [strings_1.default.DAMN, strings_1.default.OH_NO, strings_1.default.UH_OH];
function reportError(report) {
    let extraData;
    if (report.error instanceof AppError && report.error.origError) {
        extraData = {
            AppError: report.error.message,
            UserError: report.userError,
            UserDescription: report.userDescription,
            UserContact: report.userContact,
            sendPrivateData: report.sendPrivateData,
        };
        report.error = report.error.origError;
    }
    return sentry_1.reportErrorToSentry(report, extraData);
}
exports.reportError = reportError;
exports.initErrorReporting = sentry_1.initSentry;
