"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @description - Builds one {@link Transformation} from an array {@link Ordering} or {@link Filter} functions
 * @param ts - List of functions used to order or filter the credential list
 * @returns - Function combining all order / filter operations passed in
 */
exports.buildTransform = (ts) => ts
    .map(t => isFilter(t) ? filterToTransformation(t) : orderingToTransformation(t))
    .reduce((acc, curr) => (list) => curr(acc(list)), identityTransformation);
/**
 * @dev func.length checks for the number of arguments in function signature
 * @param func - The function to test
 */
const isFilter = (func) => func.length === 1;
// left commented as a converse example of isFilter
// const isOrdering = <T>(func: Filter<T> | Ordering<T>): func is Ordering<T> =>
//     func.length === 2
const filterToTransformation = (filter) => (list) => list.filter(filter);
const orderingToTransformation = (ordering) => (list) => list.sort(ordering);
const identityTransformation = (list) => list;
