"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("./filter");
const ramda_1 = require("ramda");
const expiredFilter = cred => cred.expires.valueOf() < new Date().valueOf();
const validFilter = ramda_1.complement(expiredFilter);
const issuerFilter = (issuerDid) => cred => cred.issuer === issuerDid;
const typeFilter = (typ) => cred => cred.type.includes(typ);
const mostRecentOrder = (c1, c2) => c2.issued.valueOf() - c1.issued.valueOf();
/**
 * @dev Some basic predefined filters, if required they can be removed
 * and the filtering / ordering construction functions can be exposed instead
 */
exports.filters = {
    filterByExpired: filter_1.buildTransform([expiredFilter]),
    filterByValid: filter_1.buildTransform([validFilter]),
    filterByIssuer: (did) => filter_1.buildTransform([issuerFilter(did)]),
    filterByType: (typ) => filter_1.buildTransform([typeFilter(typ)]),
    orderByRecent: filter_1.buildTransform([mostRecentOrder]),
    documentFilter: (documentTypes) => filter_1.buildTransform(documentTypes.map(typeFilter)),
};
