"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("./filter");
const ramda_1 = require("ramda");
const expiredFilter = cred => cred.expires ? cred.expires.valueOf() < new Date().valueOf() : true;
const validFilter = ramda_1.complement(expiredFilter);
const issuerFilter = (issuerDid) => cred => cred.issuer.did === issuerDid;
const typeFilter = (typ) => cred => cred.credentialType.includes(typ);
/**
 * @dev Some basic predefined filters, if required they can be removed
 * and the filtering / ordering construction functions can be exposed instead
 */
exports.filters = {
    filterByExpired: filter_1.buildTransform([expiredFilter]),
    filterByValid: filter_1.buildTransform([validFilter]),
    filterByIssuer: (did) => filter_1.buildTransform([issuerFilter(did)]),
    filterByType: (typ) => filter_1.buildTransform([typeFilter(typ)]),
    documentFilter: (documentTypes) => filter_1.buildTransform(documentTypes.map(typeFilter)),
};
