"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const rn_fetch_blob_1 = tslib_1.__importDefault(require("rn-fetch-blob"));
const form_data_1 = tslib_1.__importDefault(require("form-data"));
class IpfsCustomConnector {
    constructor(config) {
        this.nativeLib = rn_fetch_blob_1.default;
        this.ipfsHost = `${config.protocol}://${config.host}:${config.port}`;
    }
    storeJSON({ data, pin, }) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!data || typeof data !== 'object') {
                throw new Error(`JSON expected, received ${typeof data}`);
            }
            // TODO: clarify if we need formData
            // const formData = new FormData()
            // formData.append('file', Buffer.from(JSON.stringify(data)))
            const endpoint = `${this.ipfsHost}/api/v0/add?pin=${pin}`;
            const headers = { 'Content-Type': 'multipart/form-data' };
            const res = yield this.nativeLib.fetch('POST', endpoint, headers, [
                {
                    name: 'ddo',
                    data: JSON.stringify(data),
                },
            ]);
            return res.json().Hash;
        });
    }
    catJSON(hash) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const endpoint = `${this.ipfsHost}/api/v0/cat?arg=${hash}`;
            const res = yield this.nativeLib.fetch('GET', endpoint);
            return res.json();
        });
    }
    removePinnedHash(hash) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const resolutionGateway = 'https://ipfs.io/ipfs/';
            const endpoint = `${resolutionGateway}/${hash}`;
            const res = yield this.nativeLib.fetch('GET', endpoint);
            if (res.respInfo.status !== 200) {
                throw new Error(`Removing pinned hash ${hash} failed, status code: ${res.respInfo.status}`);
            }
        });
    }
    createDagObject({ data, pin, }) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!data || typeof data !== 'object') {
                throw new Error(`Object expected, received ${typeof data}`);
            }
            const formData = new form_data_1.default();
            formData.append('file', Buffer.from(JSON.stringify(data)));
            const endpoint = `${this.ipfsHost}/api/v0/dag/put?pin=${pin}`;
            const headers = { 'Content-Type': 'multipart/form-data' };
            const res = this.nativeLib.fetch('POST', endpoint, headers, [
                {
                    name: 'dag',
                    data: formData,
                },
            ]);
            return (yield res).json().Cid['/'];
        });
    }
    resolveIpldPath(pathToResolve) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const endpoint = `${this.ipfsHost}/api/v0/dag/get?arg=${pathToResolve}`;
            const res = this.nativeLib.fetch('GET', endpoint);
            return (yield res).json();
        });
    }
}
exports.IpfsCustomConnector = IpfsCustomConnector;
