"use strict";
/**
 * This migration re-encrypts the encryptedEntropy in the wallet database using
 * the jolocom-lib (which uses node crypto) instead of the previously used
 * crypto-js dependency
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cryptojs_1 = require("src/lib/compat/cryptojs");
class ReencryptSeed1567674609659 {
    up(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const entries = yield queryRunner.query('SELECT encryptedEntropy FROM master_keys;');
            if (!entries.length)
                return;
            let password;
            try {
                // If there are keys to re-encrypt, then we need to get the password.
                password = yield getPassword();
            }
            catch (e) {
                // This may fail if the application was uninstalled and reinstalled, as
                // the android keystore is cleared on uninstall, but the database may
                // still remain (and is probably pre-migrations, given that this is
                // running in the first place). In that case we take no action, and let
                // the app init code handle things
                return;
            }
            yield Promise.all(entries.map((obj) => {
                const encryptedEntropy = obj.encryptedEntropy;
                // encryptedEntropy is base64 encoded in the latest release (1.6.0), but is
                // hex encoded on the current develop branch (unreleased), and also
                // doesn't need re-encryption if it was created by code in the current
                // develop (already not using crypto-js)
                const reencrypted = encryptedEntropy.replace(/[0-9a-f]+/, '') != '' ?
                    cryptojs_1.reencryptWithJolocomLib(encryptedEntropy, password) :
                    encryptedEntropy;
                return queryRunner.query(`UPDATE master_keys ` +
                    `SET encryptedEntropy = '${reencrypted}' ` +
                    `WHERE encryptedEntropy = '${encryptedEntropy}'`);
            }));
        });
    }
    down(queryRunner) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            throw new Error("There's no going back");
            // because why?
        });
    }
}
exports.ReencryptSeed1567674609659 = ReencryptSeed1567674609659;
function getPassword() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        // At the time of writing this file, the encryption password is stored in
        // react-native-keychain and accessesed through src/lib/keychain.ts, but code
        // is reproduced here in case things change in the future
        // @ts-ignore
        if (typeof navigator !== 'undefined' && navigator.product == 'ReactNative') {
            // We load react-native-keychain here conditionally because it is not
            // transpiled and cannot be loaded into ts-node (if running migrations locally
            // on dev machine)
            const Keychain = require('react-native-keychain');
            const keyChainData = yield Keychain.getGenericPassword();
            if (keyChainData && keyChainData.password) {
                return keyChainData.password;
            }
            else {
                throw new Error("Can't load password from react-native-keychain");
            }
        }
        else {
            const password = process.env.SMARTWALLET_PASSWORD;
            if (!password) {
                throw new Error("Node envrionment detected. " +
                    "Please set a password in the environment variable SMARTWALLET_PASSWORD");
            }
            return password;
        }
    });
}
