"use strict";
/**
 * This file contains polyfills for various things that are somehow coupled
 * with react-native. This is meant to be used as a polyfill for running the
 * backendMiddleware and redux store under node
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
function logCall(pref) {
    return (msg) => console.log(`${pref}: ${msg}`);
}
const backendMiddleware_1 = require("src/backendMiddleware");
const redux_1 = require("redux");
const redux_thunk_1 = tslib_1.__importDefault(require("redux-thunk"));
const reducers_1 = require("src/reducers");
const ormconfig = require('../ormconfig.ts').default;
// change type to 'sqlite' instead of 'react-native'
ormconfig.type = 'sqlite';
ormconfig.database = 'db.sqlite3';
function initStore() {
    const config = require('src/config.ts');
    config.typeOrmConfig = ormconfig;
    // instantiate the storage backend
    const backendMiddleware = new backendMiddleware_1.BackendMiddleware(config);
    const store = Object.assign({}, redux_1.createStore(reducers_1.rootReducer, {}, redux_1.applyMiddleware(redux_thunk_1.default.withExtraArgument(backendMiddleware))), { backendMiddleware });
    return store;
}
exports.initStore = initStore;
const fs_1 = require("fs");
const path_1 = tslib_1.__importDefault(require("path"));
// from src/lib/keychain.ts
class KeyChain {
    constructor() {
        this.pass = null;
    }
    getPassword() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this.pass != null)
                return this.pass;
            try {
                this.pass = fs_1.readFileSync(KeyChain.PASSWORD_LOCATION).toString();
            }
            catch (err) {
                console.error('Error reading password file', err, '\n\n');
                throw err;
            }
            return this.pass;
        });
    }
    savePassword(pass) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            console.log('KEYCHAIN SAVED PASSWORD: ', pass);
            this.pass = pass;
            fs_1.writeFileSync(KeyChain.PASSWORD_LOCATION, pass);
        });
    }
}
KeyChain.PASSWORD_LOCATION = path_1.default.resolve(`${__dirname}/../local_identity.password.txt`);
exports.KeyChain = KeyChain;
const fetch = require('node-fetch');
const FormData = require('form-data');
var ipfs_1 = require("node_modules/jolocom-lib/js/ipfs/ipfs");
exports.IpfsCustomConnector = ipfs_1.IpfsStorageAgent;
// default export merge of all default exports
exports.default = {
    // RNFetchBlob default export
    // @ts-ignore
    fetch: function (method, endpoint, headers, formDataList) {
        console.log(arguments);
        const body = new FormData();
        formDataList.forEach((item) => {
            body.append(item.name, item.data);
        });
        return fetch(endpoint, { method, body, headers }).then((res) => {
            console.log('body', res.body.toString());
            return res;
        });
    },
    // src/locales/i18n.ts default export
    t: (str) => str,
    // react-native-splash-screen
    hide: () => logCall('SplashScreen')('hide'),
};
const crypto_1 = require("crypto");
exports.NativeModules = { RNRandomBytes: { randomBytes: crypto_1.randomBytes } };
class Linking {
    static canOpenURL(url) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            console.log('canOpenURL called with ' + url);
            return true;
        });
    }
    static openURL(url) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            console.log('openURL called with ' + url);
        });
    }
}
exports.Linking = Linking;
function initSentry() {
    console.log('initSentry');
}
exports.initSentry = initSentry;
function reportErrorToSentry(err, extraData) {
    console.error('reportErrorToSentry:\n', err.error, extraData);
}
exports.reportErrorToSentry = reportErrorToSentry;
function findBestAvailableLanguage(locales) {
    return {
        languageTag: 'en',
    };
}
exports.findBestAvailableLanguage = findBestAvailableLanguage;
